/////////////////////////////////////////////////////////////////////////////
// Chorus.cpp
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2000-2002 Grincheux  All rights reserved.
/////////////////////////////////////////////////////////////////////////////
//
//	This file is subject to the terms of the GNU General Public License as
//	published by the Free Software Foundation.  A copy of this license is
//	included with this software distribution in the file COPYING.  If you
//	do not have a copy, you may obtain a copy by writing to the Free
//	Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//
//	This software is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details
/////////////////////////////////////////////////////////////////////////////
//
// This software was based on MultiDec 5.9 Those portions are
// Copyright (C) 1999/2000 Espresso (echter_espresso@hotmail.com)
//
/////////////////////////////////////////////////////////////////////////////

// PluginAudio.cpp : Defines the entry point for the DLL application.
//
// Version simplifie du plugin
// Toute l'initialisation du son doit se faire dans le programme appelant.
#include <windows.h>

#include "../pluginaudio.h"
#include "../readwriteini.h"
#include "../HtmlHelp.H"
#include "resource.h"

extern int Prefilter, Postfilter, Pitch, Amp, table;
void InitialisationDec();
void InitialisationPreFiltre();
void InitialisationPostFiltre();
BOOL APIENTRY PluginAudioProc (HWND hDlg, UINT message,  UINT wParam, LONG lParam);

BOOL Init();
BOOL Stop();
void ShowDialog();
void Traitement (PSHORT src , PSHORT dst);
HMENU GetPluginMenu(BOOL ContextMenu);
BOOL ProcessMessage(UINT message, UINT wParam, LONG lParam,char *OSDDisplay);

ACCEL AccTable[] = {
	{ FVIRTKEY | FCONTROL, VK_F1, IDM_HELP_PLUGIN},	// HELP
	{ FVIRTKEY | FCONTROL, VK_F4, IDM_ADJUST_AUDIO},	// Bdd Rglage
	{ FVIRTKEY | FCONTROL, VK_F6, ID_OPT6},			// not used
	{ FVIRTKEY | FCONTROL, VK_F8, ID_OPT8},			// not used
	{ FVIRTKEY | FCONTROL, VK_F10, ID_OPT10},		// not used
	{ FVIRTKEY | FCONTROL, VK_F12, ID_OPT12},		// not used
};

QuenotteTV_AudioPlugin AudioPlugin =
{
	AUDIO_PLUGIN_VERSION, "Chorus-wilma 1.908 (mat)",
	0,0,0,0,0,0,0,
	AccTable, sizeof(AccTable) / sizeof(AccTable[0]),
	FALSE,

	Init, Stop, Traitement, ShowDialog, GetPluginMenu, ProcessMessage
};

char *NomFichierINI = "Plugins\\Chorus-Wilma.ini";
ConfigINI cfg[]={
//	parameter				type			variable
	{"Chorus"				,CFG_SECTION	, NULL					},
	{"AUTO_PROCESS_AUDIO"	,CFG_BOOL		,&AudioPlugin.AutoProcessAudio},
	{"NB_BUFFERS"			,CFG_INT		,&AudioPlugin.Buffers	},
	{"BUFFLEN"				,CFG_INT		,&AudioPlugin.Buflen	},
	{"PRE_FILTRE"			,CFG_INT		,&Prefilter				},
	{"POST_FILTRE"			,CFG_INT		,&Postfilter			},
	{"SOUND_FREQ"			,CFG_INT		,&AudioPlugin.Soundfreq	},
	{"PITCH"				,CFG_INT		,&Pitch					},
	{"AMP_AUDIO"			,CFG_INT		,&Amp					},
	{"PRIORITY_AUDIO"		,CFG_INT		,&AudioPlugin.Priorityaudio	},
	{"Table"				,CFG_INT		,&table	},
	{NULL, NULL ,NULL}
};







BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }
    return TRUE;
}


// Initialise le plugin
BOOL Init()
{
	AudioPlugin.Soundfreq = 44100;
	AudioPlugin.Priorityaudio=THREAD_PRIORITY_NORMAL;
	AudioPlugin.Buffers = 5;
	AudioPlugin.Buflen = 2498*2;

	ChargerINI(cfg, NomFichierINI);

	InitialisationDec();
	InitialisationPreFiltre();
	InitialisationPostFiltre(); 
	
	return TRUE;
}


BOOL Stop()
{
	SauverINI(cfg, NomFichierINI);
	return TRUE;
}


void ShowDialog()
{	
	switch (AudioPlugin.LangID)
	{
	case MAKELANGID (LANG_FRENCH, SUBLANG_DEFAULT):
		DialogBox (AudioPlugin.hDllInstance,"REGLAGES", AudioPlugin.hwndParent, (DLGPROC)PluginAudioProc);
		break;
	default://case MAKELANGID(LANG_ENGLISH, SUBLANG_DEFAULT): l'anglais est la langue par dfault
		DialogBox (AudioPlugin.hDllInstance,"REGLAGES_EN", AudioPlugin.hwndParent, (DLGPROC)PluginAudioProc);
		break;
	}
}

HMENU GetPluginMenu(BOOL ContextMenu)
{
	static HMENU CurMenu;
	switch (AudioPlugin.LangID)
	{
	
	case MAKELANGID (LANG_FRENCH, SUBLANG_DEFAULT)://default:
		if(ContextMenu)
		{
			CurMenu = LoadMenu(AudioPlugin.hDllInstance,"PLUGIN_MENU_AUDIO");
		}
		else
		{
			CurMenu = LoadMenu(AudioPlugin.hDllInstance,"PLUGIN_MENU_AUDIO");
		}
		break;

	default://case MAKELANGID(LANG_ENGLISH, SUBLANG_DEFAULT): l'anglais est la langue par dfault
		if(ContextMenu)
		{
			CurMenu = LoadMenu(AudioPlugin.hDllInstance,"PLUGIN_MENU_AUDIO_EN");
		}
		else
		{
			CurMenu = LoadMenu(AudioPlugin.hDllInstance,"PLUGIN_MENU_AUDIO_EN");
		}
		break;
	}
	return CurMenu;
}


BOOL ProcessMessage(UINT message, UINT wParam, LONG lParam,char *OSDDisplay)
{
	BOOL MessageProcessed = FALSE;
	sprintf (OSDDisplay,"");

	switch ( message) {

		case WM_COMMAND :
		
			switch( LOWORD( wParam )) {

			case IDM_ADJUST_AUDIO :
				ShowDialog();
				MessageProcessed = TRUE;
				break;

			case IDM_HELP_PLUGIN :
				HtmlHelp( GetDesktopWindow(),
						"Aide//AidePlugin.chm::/0Plugin.htm",
						HH_DISPLAY_TOPIC,
						NULL);
				MessageProcessed = TRUE;
				break;
			}
	}
	return MessageProcessed;
}


extern "C" __declspec(dllexport)
QuenotteTV_AudioPlugin* GetPlugin()
{
	return &AudioPlugin;
}
