/////////////////////////////////////////////////////////////////////////////
// ReadWriteINI.h
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2001 Quenotte  All rights reserved.
/////////////////////////////////////////////////////////////////////////////
//
//	This file is subject to the terms of the GNU General Public License as
//	published by the Free Software Foundation.  A copy of this license is
//	included with this software distribution in the file COPYING.  If you
//	do not have a copy, you may obtain a copy by writing to the Free
//	Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//
//	This software is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details
/////////////////////////////////////////////////////////////////////////////
// 
// Version 1.1 par E-nek 6/9/2001
//
// Le code a t mis dans un Header pour :
// - permettre le partage du code entre plusieurs plugin
// - permettre la compilation du code en C comme en C++.
//
// TODO:
// Optimiser le code pour rduire les accs disque ?
/////////////////////////////////////////////////////////////////////////////

#ifndef READWRITEINI_H
#define READWRITEINI_H

#include <stdio.h>
#include <stdlib.h>


///
// Remarque :
// Pour la lecture des string il faut absolument que ce soit char [] avec une taille
// suffisamment grande pour acceuillir la chaine lue.
enum TypeParametre { CFG_SECTION, CFG_INT, CFG_BOOL, CFG_BYTE, CFG_STRING};

struct ConfigINI {
	char	*NomVariable;
	int		Type;
	void	*Valeur;
};

/* 
Exemple de Structure:

int   couleur;
BOOL  bInverser;
char  Nom [40];

ConfigINI cfg[]={
//	parameter				type			variable
	// Nom de section obligatoire
	{"Section34"			,CFG_SECTION	, NULL					},

	// Quelques variables
	{"couleur"				,CFG_INT		,&couleur},
	{"inverser"				,CFG_BOOL		,&bInverser				},
	{"prenom"				,CFG_STRING		,&Nom},
	
	 // Marqueur de fin de structure obligatoire
	{NULL, 0 ,NULL}
};

*/

char CheminComplet[255];


BOOL SauverINI (struct ConfigINI cfg[], char *NomFichierINI);
BOOL ChargerINI(struct ConfigINI cfg[], char *NomFichierINI);




void ConstruireCheminComplet(char *NomFichier)
{
	GetCurrentDirectory( 255, CheminComplet);
	strcat(CheminComplet, "\\");
	strcat(CheminComplet, NomFichier);
}


BOOL SauverINI(struct ConfigINI cfg[], char *NomFichierINI)
{
char ChaineTemp[255], NomSection[255];
int i;
long tempi;

	ConstruireCheminComplet(NomFichierINI);
	i=0;
	while (cfg[i].NomVariable != NULL) {

		// Sauve le nom de la section
		if ( cfg[i].Type == CFG_SECTION ) {
			strcpy(NomSection, cfg[i].NomVariable );
			i++;
			continue;
		} 

		switch( cfg[i].Type)
		{
		
		case CFG_INT :
			sprintf(ChaineTemp, "%ld", *(int *)(cfg[i].Valeur) );
			break;
		case CFG_BYTE:
			sprintf(ChaineTemp, "%ld", *(BYTE *)(cfg[i].Valeur) );
			break;
		case CFG_BOOL:
			tempi = *(int *)(cfg[i].Valeur);
			if (tempi == 0)  
				strcpy(ChaineTemp, "False");
			else
				strcpy(ChaineTemp, "True");
			break;
		case CFG_STRING:
			strcpy(ChaineTemp,  (char *)(cfg[i].Valeur));
			break;
		}

		if (WritePrivateProfileString(NomSection, cfg[i].NomVariable, ChaineTemp, CheminComplet) == 0)
			return FALSE;
		i++;
	}
	return TRUE;
}



BOOL ChargerINI(struct ConfigINI cfg[], char *NomFichierINI)
{
char ChaineTemp[255], NomSection[255];
int i;
char *endptr;
FILE *sFile;

	ConstruireCheminComplet(NomFichierINI);
	sFile = fopen(CheminComplet, "r");
	if (sFile == NULL)
	{
		// Le fichier n'existe pas, crons un fichier INI
		// Si l'on demande  ChargerINI de lire un fichier INI inexistant,
		// il va retourner des valeurs nulles pour toutes les variables ...
		// SauverINI(cfg, NomFichierINI);

		// Il est inutile de relire ce fichier INI , on vient juste de l'crire
		// avec des valeurs "correctes" qui sont dj en mmoire.
		return FALSE;
	} else 
		fclose(sFile);


	i=0;
	while (cfg[i].NomVariable != NULL)
	{

		// La section doit tre prcis (sinon plantage)
		if ( cfg[i].Type == CFG_SECTION )
		{
			strcpy(NomSection, cfg[i].NomVariable );
			i++;
			continue;
		} 

		GetPrivateProfileString (
			NomSection,		//  
			cfg[i].NomVariable,
			"",				// Valeur par dfaut
			ChaineTemp,		// Buffer de sortie
			255,
			CheminComplet);

		if(strlen(ChaineTemp))		
		switch( cfg[i].Type)
		{
		case CFG_INT :
			*(int *)(cfg[i].Valeur) = strtol(ChaineTemp, &endptr, 10);
			break;
		case CFG_BYTE:
			*(BYTE *)(cfg[i].Valeur) = (BYTE)strtol(ChaineTemp, &endptr, 10);
			break;
		case CFG_BOOL:
			if (ChaineTemp[0] == 'T' || ChaineTemp[0] == 't')
				*(BOOL *)(cfg[i].Valeur) = TRUE;
			else 
				*(BOOL *)(cfg[i].Valeur) = FALSE;			
			break;
		case CFG_STRING:
			strcpy( (char*)cfg[i].Valeur, ChaineTemp);
			break;
		}
		i++;
	}

	return TRUE;
}

#endif